;;; DO NOT MODIFY THIS FILE
(if (featurep 'docbookide-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "docbookide/_pkg.el")

(package-provide 'docbookide :version 0.08 :author-version "0.1" :type 'regular)

;;;***

;;;### (autoloads (docbook-mode docbook-grep) "docbookide" "docbookide/docbookide.el")

(autoload 'docbook-grep "docbookide" "\
Grep for PATTERN in files matching FILESPEC.

Runs `grep' with PATTERN and FILESPEC as arguments.

PATTERN is the pattern on which `grep' is to match.  PATTERN is quoted
with single quotes in the `grep' command arguments to avoid
interpretation of characters in PATTERN.  `docbook-grep' maintains a
history of PATTERNs so you can easily re-use a previous value.

FILESPEC is the names or regular expression for the files to be
scanned by grep.  Since `docbook-grep' uses `grep', regular expressions
and multiple filenames are supported, and \"*.docbook\" and \"*.DOCBOOK
*.ent\" are both valid FILESPEC values.

When called interactively, the initial FILESPEC is taken from
docbook-default-filespec, but `docbook-grep' also maintains a history of
FILESPEC arguments so you can easily re-use a previous value.  The
history is shared with `docbook-etags' so you can re-use the same FILESPEC
with both functions." t nil)

(autoload 'docbook-mode "docbookide" "\
Major mode for editing DOCBOOK stylesheets.

Special commands:
\\{docbook-mode-map}
Turning on DOCBOOK mode calls the value of the variable `docbook-mode-hook',
if that value is non-nil.

Abbreviations:

DOCBOOK mode includes a comprehensive set of DOCBOOK-specific abbreviations
preloaded into the abbreviations table.

Font lock mode:

Turning on font lock mode causes various DOCBOOK syntactic structures to be
hightlighted.  To turn this on whenever you visit an DOCBOOK file, add
the following to your .emacs file:
  (add-hook 'docbook-mode-hook 'turn-on-font-lock)" t nil)
(add-to-list 'auto-mode-alist '("\\.docbook$" . docbook-mode))

;;;***

(provide 'docbookide-autoloads)
